# EZ-AppInstaller  
A cli tool that I have had in the back of my mind for a while, that easily installs applications that don't have an installer included. I made this mainly using ChatGPT for some weekend fun, with some aspects being made by me. Please report any issues you find :)
## Usage  
`ez-install config -d C:\foo` Would set the default directory.  
`ez-install install bar.exe` Would install bar.exe to the configured directory.  
run `ez-install --help` or `ez-install command --help` for more info.  